import React, { useState, useImperativeHandle, useCallback } from "react";

import style from "./index.module.css";
import { TextField } from "@mui/material";
import MyDialog from "@/components/mui/MyDialog";
import { Button } from "@mui/material";
import { checkIsNumberLetterChinese } from "@/utils/util";
import { useMessage } from "@/components/MySnackbar";
import { useDropzone } from "react-dropzone";
import Table from "@/components/Material.Ui/Table";
import fileIcon from "@/assets/project/fileIcon.svg";
import uploaderIcon from "@/assets/project/uploaderIcon.svg";

const UpLoaderFolder = (props: any) => {
  const [folderList, setFolderList] = useState([]);
  const { path } = props;

  const onDrop = useCallback((acceptedFiles: any) => {
    console.log(acceptedFiles);
    setFolderList(acceptedFiles);
    // Do something with the files
  }, []);
  const { getRootProps, getInputProps, isDragActive } = useDropzone({ onDrop });

  const submitloading = false;

  let dialogRef: any = React.createRef();

  const handleSubmit = () => {
    console.log("handleSubmit");
  };

  const showDialog = () => {
    dialogRef.current.handleClickOpen();
  };

  useImperativeHandle(props.onRef, () => {
    return {
      showDialog: showDialog,
    };
  });

  const folderListHeadCells = [
    { id: "name", numeric: false, label: "名称", width: "60%" },
    { id: "size", numeric: false, label: "大小", width: "25%" },
    { id: "caozuo", numeric: false, label: "操作", width: "15%" },
  ];

  const renderName = (item: any) => {
    return (
      <span className={style.folderIconBox}>
        <img className={style.folderIcon} src={fileIcon} alt="" />
        {item.name}
      </span>
    );
  };

  const renderSize = (item: any) => {
    return <span>{item.size ? `${item.size}b` : "-"}</span>;
  };

  const renderButtons = (item: any) => {
    return (
      <span>
        <Button
          sx={{ position: "relative", left: "-18px" }}
          variant="text"
          size="small"
          color="error"
        >
          删除
        </Button>
      </span>
    );
  };

  return (
    <MyDialog
      handleSubmit={handleSubmit}
      onRef={dialogRef}
      title="上传文件"
      submitloading={submitloading}
    >
      <div className={style.uploderBox}>
        <div className={style.uploderBoxLeft}>
          <div className={style.dropTitle}>添加文件</div>

          <div {...getRootProps()} className={style.dropBox}>
            <input {...getInputProps()} multiple />
            {/* <input {...getInputProps()} webkitdirectory="true" multiple /> */}
            <img className={style.uploaderIcon} src={uploaderIcon} alt="" />
            <div className={style.uploderText1}>
              点击添加文件或将文件拖到此处添加
            </div>
            <div className={style.uploderText2}>一次最多添加10个文件</div>
          </div>
        </div>
        <div className={style.folderListBox}>
          <div className={style.dropTitle}>
            已添加文件（{folderList.length}/10）
          </div>
          <div className={style.tableBox}>
            <Table
              rowHover={true}
              stickyheader={true}
              rows={folderList.map((item: any) => ({
                ...item,
                name: renderName(item),
                size: renderSize(item),
                caozuo: renderButtons(item),
              }))}
              rowsPerPage={"99"}
              headCells={folderListHeadCells}
              nopadding={true}
              footer={false}
            ></Table>
          </div>
        </div>
      </div>
    </MyDialog>
  );
};

export default UpLoaderFolder;
